# HistoryLabelRemoved

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**label_ids** | **list[str]** | Label IDs removed from the message. | [optional] 
**message** | [**Message**](Message.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

